/* disconnect.h
 *
 * $Id: disconnect.h,v 1.7 2000/04/21 22:29:36 nisse Exp $ */

/* lsh, an implementation of the ssh protocol
 *
 * Copyright (C) 1998 Niels Mller
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef LSH_DISCONNECT_H_INCLUDED
#define LSH_DISCONNECT_H_INCLUDED

#include "lsh_types.h"

struct lsh_string *format_disconnect(int code, const char *msg, 
                                     const char *language);

extern struct packet_handler disconnect_handler;

#endif /* LSH_DISCONNECT_H_INCLUDED */
